/*
 *  menu.h
 *
 *  Copyright (C) 1998 Ullrich Hafner <hafner@bigfoot.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 */

/*
 *  $Date: 2000/07/19 19:22:50 $
 *  $Author: hafner $
 *  $Revision: 1.11 $
 *  $State: Exp $
 */

#ifndef _MENU_H
#define _MENU_H

#include "misc.h"

GtkWidget *
make_toolbar (bool_t noinet);
GtkWidget *
make_menubar (GtkWidget *logwindow, bool_t themes_menu, bool_t noinet);
void
toggle_save (bool_t enable, proplist_t *key);
void
enable_revert (void);

#endif /* not _MENU_H */

